## This software falls under the GNU general public license version 3 or later.
## It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
## in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>
## Author: Lorenzo Lunelli
# set octaveX plugin to use an user selected graphics toolkit
# v 0.1 6-11-2019
# v 0.2 3-9-2020 - changed preferences from global variables to the Octave preferences framework ("OctaveX" group), preferences are: "TEXMACS_OCTAVE_PLUGIN_CONTROL", "DEF_GTKIT", "TEXMACS_OCTAVE_TMP"

function info = tmgt(choice)
	message="Valid options are: 'g'/'f'/'q'/'0'/'gnuplot'/'fltk'/'qt'/'none'";
	if (ispref ("OctaveX","DEF_GTKIT"))
		dgtk=getpref ("OctaveX","DEF_GTKIT");
		message=[message, " - actual value=",dgtk];
	endif
	if (nargin>0)
		ok=0;
		if (strcmpi (choice,'f') || strcmpi(choice,"fltk")) # fltk graphics toolkit
			if (any(strcmp("fltk",available_graphics_toolkits)))  # check if fltk graphic toolkit is available
				def_gtkit= "fltk";
				ok=1;
				message="-- OctaveX - default graphics toolkit=fltk: restart TeXmacs"; 
			else
				message="-- TeXmacs OctaveX plugin: ERROR, fltk graphics toolkit not available";
			endif
		endif
		if (strcmpi (choice,'g') || strcmpi(choice,"gnuplot")) # gnuplot graphics toolkit
			if (any(strcmp("gnuplot",available_graphics_toolkits)))  # check if gnuplot graphic toolkit is available
				def_gtkit= "gnuplot";
				ok=1;
				message="-- OctaveX - default graphics toolkit=gnuplot: restart TeXmacs"; 
			else
				messsage="-- TeXmacs OctaveX plugin: ERROR, gnuplot graphics toolkit not available";
			endif
		endif
		if (strcmpi (choice,'q') || strcmpi(choice,"qt")) # qt graphics toolkit
			if (any(strcmp("qt",available_graphics_toolkits)))  # check if qt graphic toolkit is available
				def_gtkit= "qt";
				ok=1;
				message="-- OctaveX - default graphics toolkit=qt: restart TeXmacs";
			else
				message="-- TeXmacs OctaveX plugin: ERROR, qt graphics toolkit not available";
			endif
		endif
		if (strcmpi (choice,'0') || strcmpi(choice,"none")) # no deafault graphics toolkit
			message="-- OctaveX - no default graphics toolkit: restart TeXmacs";
			def_gtkit= "none";
			if (ispref ("OctaveX","DEF_GTKIT")) 
				rmpref ("OctaveX","DEF_GTKIT")
			endif
			ok=0;
		endif
		if (ok)
			setpref ("OctaveX","DEF_GTKIT",def_gtkit)
		endif
	endif
	info=message;
endfunction
